@@ -26,11 +26,20 @@ class Utils():
 
     @staticmethod
     def parse_version(version_str):
-        version_info = (re.findall(r"Ver (\d+)\.([0-9.]+)\-(\w+)", version_str))
-        version_major = int(version_info[0][0])
-        version_minor = version_info[0][1]
-        version_variant = version_info[0][2].lower()
-        if version_major == 8:
-            version_variant = "mysql"
+        version_info = (re.findall(r"Ver ([0-9.]+)\-?([a-zA-Z0-9.-]+)? for", version_str))
+        if version_info:
+            (version_major, version_minor) = version_info[0][0].split('.', 1)
+            version_major = int(version_major)
+
+            if "mariadb" in version_info[0][1].lower():
+                version_variant = "mariadb"
+            elif version_major == 8:
+                version_variant = "mysql"
+            else:
+                version_variant = "unknown"
+        else:
+            version_variant = None
+            version_major = None
+            version_minor = None
 
         return (version_variant, version_major, version_minor)
