@@ -9,6 +9,30 @@ def test_log_levelset_noexception():
     assert True
 
 
+@pytest.mark.log_test
+def test_log_levelset_info_noexception():
+    logger.setlevel('INFO')
+    assert True
+
+
+@pytest.mark.log_test
+def test_log_levelset_debug_noexception():
+    logger.setlevel('DEBUG')
+    assert True
+
+
+@pytest.mark.log_test
+def test_log_levelset_error_noexception():
+    logger.setlevel('ERROR')
+    assert True
+
+
+@pytest.mark.log_test
+def test_log_levelset_warn_noexception():
+    logger.setlevel('WARN')
+    assert True
+
+
 @pytest.mark.log_test
 def test_log_levelset_fail():
     with pytest.raises(InvalidLogLevel):
